{"sun/audioio.h",	"AUDIO_DRAIN",	0x20004103},
{"sun/isdnio.h",	"ISDN_PH_ACTIVATE_REQ",	0x2000410a},
{"sun/isdnio.h",	"ISDN_MPH_DEACTIVATE_REQ",	0x2000410b},
{"sun/fbio.h",	"FBIO_WID_DBL_SET",	0x20004625},
{"pixrect/gp1var.h",	"GP1IO_SCMAP",	0x20004766},
{"sun/mem.h",	"MM_HRCNT",	0x20004d02},
{"sundev/openpromio.h",	"OPROMGETOPT",	0x20004f01},
{"sundev/openpromio.h",	"OPROMSETOPT",	0x20004f02},
{"sundev/openpromio.h",	"OPROMNXTOPT",	0x20004f03},
{"sundev/openpromio.h",	"OPROMSETOPT2",	0x20004f04},
{"sundev/openpromio.h",	"OPROMNEXT",	0x20004f05},
{"sundev/openpromio.h",	"OPROMCHILD",	0x20004f06},
{"sundev/openpromio.h",	"OPROMGETPROP",	0x20004f07},
{"sundev/openpromio.h",	"OPROMNXTPROP",	0x20004f08},
{"sundev/openpromio.h",	"OPROMU2P",	0x20004f09},
{"sundev/openpromio.h",	"OPROMGETCONS",	0x20004f0a},
{"stropts.h",	"I_POP",	0x20005303},
{"sys/stropts.h",	"I_POP",	0x20005303},
{"stropts.h",	"I_FLUSH",	0x20005305},
{"sys/stropts.h",	"I_FLUSH",	0x20005305},
{"sys/stropts.h",	"I_SRDOPT",	0x20005306},
{"stropts.h",	"I_SRDOPT",	0x20005306},
{"sys/stropts.h",	"I_SETSIG",	0x20005309},
{"stropts.h",	"I_SETSIG",	0x20005309},
{"sys/stropts.h",	"I_LINK",	0x2000530c},
{"stropts.h",	"I_LINK",	0x2000530c},
{"sys/stropts.h",	"I_UNLINK",	0x2000530d},
{"stropts.h",	"I_UNLINK",	0x2000530d},
{"sys/stropts.h",	"I_SENDFD",	0x20005311},
{"stropts.h",	"I_SENDFD",	0x20005311},
{"sys/stropts.h",	"I_PLINK",	0x20005313},
{"stropts.h",	"I_PLINK",	0x20005313},
{"stropts.h",	"I_PUNLINK",	0x20005314},
{"sys/stropts.h",	"I_PUNLINK",	0x20005314},
{"termio.h",	"TCSBRK",	0x20005405},
{"sys/termio.h",	"TCSBRK",	0x20005405},
{"termios.h",	"TCXONC",	0x20005406},
{"sys/termios.h",	"TCXONC",	0x20005406},
{"sys/termios.h",	"TCFLSH",	0x20005407},
{"termios.h",	"TCFLSH",	0x20005407},
{"sun/tvio.h",	"TVIOGRAB",	0x2000581d},
{"sun/tvio.h",	"TVIORELEASE",	0x2000581e},
{"sun/tvio.h",	"TVIOREDIRECT",	0x20005822},
{"sun/tvio.h",	"TVIOSYNC",	0x20005825},
{"sun/tvio.h",	"TVIOVWAIT",	0x2000582d},
{"sun/tvio.h",	"TVIOSLOOPBACKCAL",	0x2000583d},
{"sbusdev/bpp_io.h",	"BPPIOC_TESTIO",	0x20006206},
{"scsi/targets/srdef.h",	"CDROMPAUSE",	0x2000630a},
{"sundev/srreg.h",	"CDROMPAUSE",	0x2000630a},
{"sundev/srreg.h",	"CDROMRESUME",	0x2000630b},
{"sundev/srreg.h",	"CDROMSTOP",	0x20006369},
{"scsi/targets/srdef.h",	"CDROMSTOP",	0x20006369},
{"scsi/targets/srdef.h",	"CDROMSTART",	0x2000636a},
{"sundev/srreg.h",	"CDROMSTART",	0x2000636a},
{"scsi/targets/srdef.h",	"CDROMEJECT",	0x2000636b},
{"sundev/srreg.h",	"CDROMEJECT",	0x2000636b},
{"sun/dkio.h",	"FDKEJECT",	0x20006470},
{"sys/filio.h",	"FIOCLEX",	0x20006601},
{"sys/filio.h",	"FIONCLEX",	0x20006602},
{"sys/filio.h",	"FIOLFS",	0x20006640},
{"sys/filio.h",	"FIOLFSS",	0x20006641},
{"sys/filio.h",	"FIOFFS",	0x20006642},
{"sys/filio.h",	"FIOAI",	0x20006643},
{"sys/filio.h",	"FIODUTIMES",	0x20006644},
{"sys/filio.h",	"FIODIO",	0x20006645},
{"sys/filio.h",	"FIODIOS",	0x20006646},
{"sunwindow/win_ioctl.h",	"WININSERT",	0x20006703},
{"sunwindow/win_ioctl.h",	"WINREMOVE",	0x20006704},
{"sunwindow/win_ioctl.h",	"WINCOMPUTECLIPPING",	0x20006712},
{"sunwindow/win_ioctl.h",	"WINLOCKDATA",	0x20006715},
{"sunwindow/win_ioctl.h",	"WINUNLOCKDATA",	0x20006716},
{"sunwindow/win_ioctl.h",	"WINGRABIO",	0x20006717},
{"sunwindow/win_ioctl.h",	"WINRELEASEIO",	0x20006718},
{"sunwindow/win_ioctl.h",	"WINUNLOCKEVENT",	0x2000671c},
{"sunwindow/win_ioctl.h",	"WINUNLOCKSCREEN",	0x2000671e},
{"sunwindow/win_ioctl.h",	"WINSCREENDESTROY",	0x2000672a},
{"sunwindow/win_ioctl.h",	"WINPRINT",	0x2000672c},
{"sunwindow/win_ioctl.h",	"WINREFUSEKBDFOCUS",	0x2000673a},
{"sunwindow/win_ioctl.h",	"WINDBLACCESS",	0x20006747},
{"sunwindow/win_ioctl.h",	"WINDBLFLIP",	0x20006748},
{"sunwindow/win_ioctl.h",	"WINDBLABSORB",	0x20006749},
{"sunwindow/win_ioctl.h",	"WINDBLRLSE",	0x2000674a},
{"sunwindow/win_ioctl.h",	"WINSHAREQUEUE",	0x20006750},
{"sunwindow/win_ioctl.h",	"WINDISCONNECT",	0x20006798},
{"sunwindow/win_ioctl.h",	"WINRECONNECT",	0x20006799},
{"sun/ndio.h",	"NDIOCSON",	0x20006e00},
{"sun/ndio.h",	"NDIOCSOFF",	0x20006e01},
{"sun/ndio.h",	"NDIOCCLEAR",	0x20006e05},
{"net/nit_buf.h",	"NIOCCTIME",	0x20007008},
{"sys/ttold.h",	"TIOCHPCL",	0x20007402},
{"sbusdev/gtreg.h",	"FB_SETSERVER",	0x20007407},
{"sys/ttold.h",	"TIOCEXCL",	0x2000740d},
{"sys/ttold.h",	"TIOCNXCL",	0x2000740e},
{"sbusdev/gtreg.h",	"FB_DISCONNECT",	0x20007410},
{"sbusdev/gtreg.h",	"FB_UNGRABHW",	0x20007414},
{"sys/ttycom.h",	"TIOCCONS",	0x20007424},
{"sys/ttold.h",	"_O_TIOCCONS",	0x20007468},
{"sys/ttold.h",	"TIOCSTART",	0x2000746e},
{"sys/ttold.h",	"TIOCSTOP",	0x2000746f},
{"sys/ttycom.h",	"TIOCNOTTY",	0x20007471},
{"sys/ttold.h",	"TIOCCDTR",	0x20007478},
{"sys/ttold.h",	"TIOCSDTR",	0x20007479},
{"sys/ttold.h",	"TIOCCBRK",	0x2000747a},
{"sys/ttold.h",	"TIOCSBRK",	0x2000747b},
{"sys/ttycom.h",	"TIOCSCTTY",	0x20007484},
{"sun/gpio.h",	"GP1IO_GET_TRUMINORDEV",	0x40014708},
{"sundev/kbio.h",	"KIOCGLED",	0x40016b0f},
{"sundev/ppreg.h",	"PPIOCGETS",	0x40017000},
{"sundev/ppreg.h",	"PPIOCGETC",	0x40017001},
{"sun/gpio.h",	"GP1IO_GET_REQDEV",	0x40024707},
{"sun/tvio.h",	"TVIOGBIND",	0x4002581f},
{"sbusdev/bpp_io.h",	"BPPIOC_GETOUTPINS",	0x40026204},
{"sundev/srreg.h",	"CDROMREADTOCHDR",	0x40026367},
{"sbusdev/bpp_io.h",	"BPPIOC_GETERR",	0x40036205},
{"sun/audioio.h",	"AUDIO_GETDEV",	0x40044104},
{"sun/fbio.h",	"FBIOGVIDEO",	0x40044608},
{"sun/fbio.h",	"GRABPAGEALLOC",	0x4004460a},
{"sun/fbio.h",	"FBIOGPLNGRP",	0x4004460d},
{"sun/fbio.h",	"FBIOGCMSIZE",	0x4004460e},
{"sun/fbio.h",	"FBIOAVAILPLNGRP",	0x40044611},
{"sun/fbio.h",	"FBIOSWINFD",	0x40044614},
{"sun/fbio.h",	"FBIOSAVWINFD",	0x40044615},
{"sun/fbio.h",	"FBIORESWINFD",	0x40044616},
{"sun/fbio.h",	"FBIOSRWINFD",	0x40044617},
{"sun/fbio.h",	"FBIOGCURMAX",	0x4004461c},
{"sun/fbio.h",	"GRABLOCKINFO",	0x4004461d},
{"sun/fbio.h",	"FBIO_DEVID",	0x40044622},
{"sun/fbio.h",	"FBIO_FULLSCREEN_ELIMINATION_GROUPS",	0x40044624},
{"sun/fbio.h",	"FBIOVRTOFFSET",	0x40044626},
{"sun/gpio.h",	"GP1IO_GET_STATIC_BLOCK",	0x40044701},
{"sun/gpio.h",	"GP1IO_GET_GBUFFER_STATE",	0x40044703},
{"sun/gpio.h",	"GP1IO_GET_RESTART_COUNT",	0x40044705},
{"sun/gpio.h",	"GP1IO_CHK_FOR_GBUFFER",	0x40044709},
{"stropts.h",	"I_NREAD",	0x40045301},
{"sys/stropts.h",	"I_NREAD",	0x40045301},
{"sys/stropts.h",	"I_GRDOPT",	0x40045307},
{"stropts.h",	"I_GRDOPT",	0x40045307},
{"sys/stropts.h",	"I_GETSIG",	0x4004530a},
{"stropts.h",	"I_GETSIG",	0x4004530a},
{"sun/tvio.h",	"TVIOGFORMAT",	0x40045801},
{"sun/tvio.h",	"TVIOGCOMPOUT",	0x40045803},
{"sun/tvio.h",	"TVIOGSYNC",	0x40045805},
{"pixrect/cg8var.h",	"PIPIO_G_PIP_ON_OFF",	0x40045805},
{"sun/tvio.h",	"TVIOGOUT",	0x40045807},
{"sun/tvio.h",	"TVIOGCOMPRESS",	0x40045809},
{"pixrect/cg8var.h",	"PIPIO_G_PIP_ON_OFF_RESUME",	0x40045809},
{"pixrect/cg8var.h",	"PIPIO_G_PIP_ON_OFF_SUSPEND",	0x4004580a},
{"sun/tvio.h",	"TVIOGCHROMAGAIN",	0x4004580b},
{"sun/tvio.h",	"TVIOGREDGAIN",	0x4004580d},
{"sun/tvio.h",	"TVIOGREDBLACK",	0x4004580f},
{"sun/tvio.h",	"TVIOGGREENGAIN",	0x40045811},
{"sun/tvio.h",	"TVIOGGREENBLACK",	0x40045813},
{"sun/tvio.h",	"TVIOGBLUEGAIN",	0x40045815},
{"sun/tvio.h",	"TVIOGBLUEBLACK",	0x40045817},
{"sun/tvio.h",	"TVIOGLUMAGAIN",	0x40045819},
{"sun/tvio.h",	"TVIOGBTYPE",	0x40045821},
{"sun/tvio.h",	"TVIOGLIVE",	0x40045823},
{"sun/tvio.h",	"TVIOGCHROMASEP",	0x40045827},
{"pixrect/cg8var.h",	"PIPIO_G_CURSOR_COLOR_FREEZE",	0x40045828},
{"sun/tvio.h",	"TVIOGCHROMADEMOD",	0x40045829},
{"pixrect/cg8var.h",	"PIPIO_G_TEST",	0x4004582b},
{"sun/tvio.h",	"TVIOGGENLOCK",	0x4004582b},
{"sun/tvio.h",	"TVIOGSYNCABSENT",	0x4004582e},
{"sun/tvio.h",	"TVIOGBURSTABSENT",	0x4004582f},
{"sun/tvio.h",	"TVIOGIBSTATE",	0x40045837},
{"sun/tvio.h",	"TVIOGABSTATE",	0x40045839},
{"sun/tvio.h",	"TVIOGCONTROL",	0x4004583b},
{"sun/dkio.h",	"FDKGETCHANGE",	0x4004646f},
{"sys/filio.h",	"FIOGETOWN",	0x4004667b},
{"sys/filio.h",	"FIONREAD",	0x4004667f},
{"sunwindow/win_ioctl.h",	"WINGETUSERFLAGS",	0x4004670e},
{"sunwindow/win_ioctl.h",	"WINGETOWNER",	0x40046710},
{"sunwindow/win_ioctl.h",	"WINGETBUTTONORDER",	0x40046724},
{"sunwindow/win_ioctl.h",	"WINGETNEXTINPUT",	0x40046739},
{"sunwindow/win_ioctl.h",	"WINGETPLANEGROUP",	0x40046740},
{"sunwindow/win_ioctl.h",	"WINGETNOTIFYALL",	0x40046751},
{"sundev/kbio.h",	"KIOCGTRANS",	0x40046b05},
{"sundev/kbio.h",	"KIOCGTRANSABLE",	0x40046b07},
{"sundev/kbio.h",	"KIOCTYPE",	0x40046b09},
{"sundev/kbio.h",	"KIOCGDIRECT",	0x40046b0b},
{"sundev/kbio.h",	"KIOCGCOMPAT",	0x40046b11},
{"sundev/kbio.h",	"KIOCLAYOUT",	0x40046b14},
{"sys/sockio.h",	"SIOCGHIWAT",	0x40047301},
{"sys/sockio.h",	"SIOCGLOWAT",	0x40047303},
{"sys/sockio.h",	"SIOCATMARK",	0x40047307},
{"sys/sockio.h",	"SIOCGPGRP",	0x40047309},
{"sys/ttold.h",	"TIOCGETD",	0x40047400},
{"sys/ttold.h",	"TIOCMODG",	0x40047403},
{"sbusdev/gtreg.h",	"FB_GETWPART",	0x4004740a},
{"sbusdev/gtreg.h",	"FB_GETMONITOR",	0x4004740c},
{"sbusdev/gtreg.h",	"FB_GRABHW",	0x40047413},
{"sbusdev/gtreg.h",	"FB_GETCLUTPART",	0x40047418},
{"sys/ttold.h",	"TIOCGETX",	0x40047423},
{"sys/ttycom.h",	"TIOCGSOFTCAR",	0x40047464},
{"sys/ttycom.h",	"TIOCMGET",	0x4004746a},
{"sys/ttycom.h",	"TIOCOUTQ",	0x40047473},
{"sys/ttycom.h",	"TIOCGPGRP",	0x40047477},
{"sys/ttold.h",	"TIOCLGET",	0x4004747c},
{"sys/ttycom.h",	"TIOCISPACE",	0x40047480},
{"sys/ttycom.h",	"TIOCISIZE",	0x40047481},
{"sys/ttycom.h",	"TIOCGETPGRP",	0x40047483},
{"sys/vcmd.h",	"VGETSTATE",	0x40047600},
{"sundev/vuid_event.h",	"VUIDGFORMAT",	0x40047602},
{"sun/dkio.h",	"DKIOCGTYPE",	0x4006647c},
{"sys/ttold.h",	"TIOCGETP",	0x40067408},
{"sys/ttold.h",	"TIOCGETC",	0x40067412},
{"sys/ttold.h",	"TIOCGLTC",	0x40067474},
{"sun/tvio.h",	"TVIOGPOS",	0x4008581b},
{"sun/dkio.h",	"DKIOCGPART",	0x40086404},
{"sun/dkio.h",	"FDKGETSEARCH",	0x4008646c},
{"sunwindow/win_ioctl.h",	"WINNEXTFREE",	0x40086705},
{"sunwindow/win_ioctl.h",	"WINGETRECT",	0x4008670a},
{"sunwindow/win_ioctl.h",	"WINGETSAVEDRECT",	0x4008670d},
{"sunwindow/win_ioctl.h",	"WINGETEVENTTIMEOUT",	0x4008673c},
{"sunwindow/win_ioctl.h",	"WINDBLCURRENT",	0x4008674d},
{"sun/sqz.h",	"SQZGET",	0x40087102},
{"sbusdev/gtreg.h",	"FB_GETLIGHTPENPARAM",	0x4008741b},
{"sbusdev/gtreg.h",	"FB_GETGAMMA",	0x40087420},
{"sys/ttycom.h",	"TIOCGSIZE",	0x40087426},
{"sys/ttold.h",	"_O_TIOCGSIZE",	0x40087466},
{"sys/ttycom.h",	"TIOCGWINSZ",	0x40087468},
{"sun/dkio.h",	"DKIOCINFO",	0x400c6408},
{"sun/dkio.h",	"DKIOCGDIAG",	0x400c6474},
{"sun/dkio.h",	"DKIOCGLOG",	0x400c6476},
{"sunwindow/win_ioctl.h",	"WINGETFOCUSEVENT",	0x400c6747},
{"sunwindow/win_ioctl.h",	"WINGETSWALLOWEVENT",	0x400c6749},
{"pixrect/cg8var.h",	"PIPIO_G_EMULATION_MODE",	0x400e5803},
{"sun/fbio.h",	"FBIOGXINFO",	0x40104627},
{"sys/stropts.h",	"I_RECVFD",	0x40105312},
{"stropts.h",	"I_RECVFD",	0x40105312},
{"sunwindow/win_ioctl.h",	"WINGETSCREENPOSITIONS",	0x4010672d},
{"scsi/targets/stdef.h",	"STIOCGET",	0x40106d02},
{"sundev/streg.h",	"STIOCGET",	0x40106d02},
{"sys/termio.h",	"TCGETA",	0x40125401},
{"termio.h",	"TCGETA",	0x40125401},
{"sunwindow/win_ioctl.h",	"WINGETAVAILPLANEGROUPS",	0x40146742},
{"sun/fbio.h",	"FBIOGTYPE",	0x40184600},
{"sun/fbio.h",	"FBIOGINFO",	0x40184602},
{"sun/fbio.h",	"FBIODBLGINFO",	0x40184612},
{"sys/mtio.h",	"MTIOCGET",	0x40186d02},
{"sun/dkio.h",	"FDKIOGCHAR",	0x401c6472},
{"sun/fbio.h",	"FBIOMONINFO",	0x40204628},
{"sbusdev/bpp_io.h",	"BPPIOC_GETPARMS",	0x40206202},
{"sbusdev/gtreg.h",	"FB_GT_GETVERSION",	0x40207429},
{"sys/termios.h",	"TCGETS",	0x40245408},
{"termios.h",	"TCGETS",	0x40245408},
{"sun/dkio.h",	"DKIOCGGEOM",	0x40266402},
{"sunwindow/win_ioctl.h",	"WINGETKBDMASK",	0x40346734},
{"sunwindow/win_ioctl.h",	"WINGETPICKMASK",	0x40346735},
{"sun/dkio.h",	"FDKGETDRIVECHAR",	0x4038646e},
{"sun/dkio.h",	"DKIOCGCONF",	0x403c647e},
{"sun/tvio.h",	"TVIOGVIDEOCAL",	0x40405831},
{"sun/tvio.h",	"TVIONVREAD",	0x40405833},
{"sun/dkio.h",	"DKIOCGAPART",	0x4040647a},
{"sunwindow/win_ioctl.h",	"WINGETSCALING",	0x40406726},
{"sun/fbio.h",	"FBIOGATTR",	0x40584606},
{"sunwindow/win_ioctl.h",	"WINSCREENGET",	0x40646729},
{"sunwindow/win_ioctl.h",	"WINGETINPUTMASK",	0x406c6713},
{"sun/audioio.h",	"AUDIO_GETINFO",	0x40844101},
{"pixrect/cg8var.h",	"PIPIO_G_FB_INFO",	0x40d05801},
{"sundev/kbio.h",	"KIOCSLED",	0x80016b0e},
{"sundev/ppreg.h",	"PPIOCSETC",	0x80017002},
{"sys/ttycom.h",	"TIOCSTI",	0x80017472},
{"sun/tvio.h",	"TVIOSBIND",	0x80025820},
{"sbusdev/bpp_io.h",	"BPPIOC_SETOUTPINS",	0x80026203},
{"sun/isdnio.h",	"ISDN_MESSAGE_SET",	0x8004410c},
{"sun/fbio.h",	"FBIOSVIDEO",	0x80044607},
{"sun/fbio.h",	"FBIOVERTICAL",	0x80044609},
{"sun/fbio.h",	"GRABPAGEFREE",	0x8004460b},
{"sun/fbio.h",	"GRABATTACH",	0x8004460c},
{"sun/fbio.h",	"FBIOSCMSIZE",	0x8004460f},
{"sun/fbio.h",	"FBIOSCMS",	0x80044610},
{"sun/fbio.h",	"FBIOSCURPOS",	0x8004461a},
{"sun/fbio.h",	"FBIOGCURPOS",	0x8004461b},
{"sun/fbio.h",	"FBIO_U_RST",	0x80044623},
{"sun/gpio.h",	"GP1IO_FREE_STATIC_BLOCK",	0x80044702},
{"sun/gpio.h",	"GP1IO_CHK_GP",	0x80044704},
{"sun/gpio.h",	"GP1IO_REDIRECT_DEVFB",	0x80044706},
{"sun/gpio.h",	"GP1IO_SET_USING_GBUFFER",	0x8004470a},
{"sun/mem.h",	"MM_CCRW",	0x80044d03},
{"sun/mem.h",	"MM_PCNT0",	0x80044d04},
{"sun/mem.h",	"MM_PCNT1",	0x80044d05},
{"sun/vddrv.h",	"VDFREEVADDR",	0x80045604},
{"sun/tvio.h",	"TVIOSFORMAT",	0x80045802},
{"sun/tvio.h",	"TVIOSCOMPOUT",	0x80045804},
{"sun/tvio.h",	"TVIOSSYNC",	0x80045806},
{"pixrect/cg8var.h",	"PIPIO_S_PIP_ON_OFF",	0x80045807},
{"sun/tvio.h",	"TVIOSOUT",	0x80045808},
{"sun/tvio.h",	"TVIOSCOMPRESS",	0x8004580a},
{"sun/tvio.h",	"TVIOSCHROMAGAIN",	0x8004580c},
{"sun/tvio.h",	"TVIOSREDGAIN",	0x8004580e},
{"sun/tvio.h",	"TVIOSREDBLACK",	0x80045810},
{"sun/tvio.h",	"TVIOSGREENGAIN",	0x80045812},
{"sun/tvio.h",	"TVIOSGREENBLACK",	0x80045814},
{"sun/tvio.h",	"TVIOSBLUEGAIN",	0x80045816},
{"sun/tvio.h",	"TVIOSBLUEBLACK",	0x80045818},
{"sun/tvio.h",	"TVIOSLUMAGAIN",	0x8004581a},
{"sun/tvio.h",	"TVIOSLIVE",	0x80045824},
{"sun/tvio.h",	"TVIOSCHROMASEP",	0x80045828},
{"pixrect/cg8var.h",	"PIPIO_S_CURSOR_COLOR_FREEZE",	0x80045829},
{"pixrect/cg8var.h",	"PIPIO_S_MAP_SLOT",	0x8004582a},
{"sun/tvio.h",	"TVIOSCHROMADEMOD",	0x8004582a},
{"pixrect/cg8var.h",	"PIPIO_S_TEST",	0x8004582c},
{"sun/tvio.h",	"TVIOSGENLOCK",	0x8004582c},
{"sun/tvio.h",	"TVIOSIBADVANCE",	0x80045835},
{"sun/tvio.h",	"TVIOSABSTATE",	0x80045838},
{"sun/tvio.h",	"TVIOSCONTROL",	0x8004583c},
{"sundev/srreg.h",	"CDROMPLAYTRKIND",	0x8004630d},
{"scsi/targets/srdef.h",	"CDROMPLAYTRKIND",	0x8004630d},
{"sundev/srreg.h",	"CDROMVOLCTRL",	0x8004630e},
{"sun/dkio.h",	"DKIOCGBAD",	0x80046478},
{"sun/dkio.h",	"DKIOCSBAD",	0x80046479},
{"sys/filio.h",	"FIOSETOWN",	0x8004667c},
{"sys/filio.h",	"FIOASYNC",	0x8004667d},
{"sys/filio.h",	"FIONBIO",	0x8004667e},
{"sunwindow/win_ioctl.h",	"WINSETMOUSE",	0x80046706},
{"sunwindow/win_ioctl.h",	"WINSETUSERFLAGS",	0x8004670f},
{"sunwindow/win_ioctl.h",	"WINSETOWNER",	0x80046711},
{"sunwindow/win_ioctl.h",	"WINDONEDAMAGED",	0x80046721},
{"sunwindow/win_ioctl.h",	"WINSETBUTTONORDER",	0x80046725},
{"sunwindow/win_ioctl.h",	"WINSETNEXTINPUT",	0x80046738},
{"sunwindow/win_ioctl.h",	"WINSETKBDFOCUS",	0x8004673d},
{"sunwindow/win_ioctl.h",	"WINSETPLANEGROUP",	0x8004673f},
{"sunwindow/win_ioctl.h",	"WINSETNOTIFYALL",	0x80046752},
{"sunwindow/win_ioctl.h",	"WINSETRECQUE",	0x800467c8},
{"sunwindow/win_ioctl.h",	"WINSETRECORD",	0x800467c9},
{"sunwindow/win_ioctl.h",	"WINSETPLAYBACK",	0x800467cb},
{"sys/sockio.h",	"SIOCSPROMISC",	0x80046930},
{"sundev/kbio.h",	"KIOCTRANS",	0x80046b00},
{"sundev/kbio.h",	"KIOCTRANSABLE",	0x80046b06},
{"sundev/kbio.h",	"KIOCCMD",	0x80046b08},
{"sundev/kbio.h",	"KIOCSDIRECT",	0x80046b0a},
{"sundev/kbio.h",	"KIOCSCOMPAT",	0x80046b10},
{"sun/ndio.h",	"NDIOCSAT",	0x80046e04},
{"sun/ndio.h",	"NDIOCVER",	0x80046e07},
{"net/nit_if.h",	"NIOCSFLAGS",	0x80047004},
{"net/nit_if.h",	"NIOCSSNAP",	0x80047006},
{"net/nit_buf.h",	"NIOCSCHUNK",	0x80047009},
{"sun/sqz.h",	"SQZSET",	0x80047101},
{"sys/sockio.h",	"SIOCSHIWAT",	0x80047300},
{"sys/sockio.h",	"SIOCSLOWAT",	0x80047302},
{"sys/sockio.h",	"SIOCSPGRP",	0x80047308},
{"sys/ttold.h",	"TIOCSETD",	0x80047401},
{"sys/ttold.h",	"TIOCMODS",	0x80047404},
{"sbusdev/gtreg.h",	"FB_FCSFREE",	0x80047406},
{"sbusdev/gtreg.h",	"FB_SETDIAGMODE",	0x80047408},
{"sbusdev/gtreg.h",	"FB_SETWPART",	0x80047409},
{"sbusdev/gtreg.h",	"FB_SETMONITOR",	0x8004740b},
{"sys/ttold.h",	"TIOCFLUSH",	0x80047410},
{"sbusdev/gtreg.h",	"FB_LOADKMCB",	0x80047411},
{"sbusdev/gtreg.h",	"FB_SETCLUTPART",	0x80047417},
{"sbusdev/gtreg.h",	"FB_LIGHTPENENABLE",	0x80047419},
{"sys/ttycom.h",	"TIOCTCNTL",	0x80047420},
{"sys/ttycom.h",	"TIOCSIGNAL",	0x80047421},
{"sys/ttold.h",	"TIOCSETX",	0x80047422},
{"sys/ttycom.h",	"TIOCSSOFTCAR",	0x80047465},
{"sys/ttycom.h",	"TIOCUCNTL",	0x80047466},
{"sys/ttycom.h",	"TIOCREMOTE",	0x80047469},
{"sys/ttycom.h",	"TIOCMBIC",	0x8004746b},
{"sys/ttycom.h",	"TIOCMBIS",	0x8004746c},
{"sys/ttycom.h",	"TIOCMSET",	0x8004746d},
{"sys/ttycom.h",	"TIOCPKT",	0x80047470},
{"sys/ttycom.h",	"TIOCSPGRP",	0x80047476},
{"sys/ttold.h",	"TIOCLSET",	0x8004747d},
{"sys/ttold.h",	"TIOCLBIC",	0x8004747e},
{"sys/ttold.h",	"TIOCLBIS",	0x8004747f},
{"sys/ttycom.h",	"TIOCSETPGRP",	0x80047482},
{"sundev/vuid_event.h",	"VUIDSFORMAT",	0x80047601},
{"sys/vcmd.h",	"VSETSTATE",	0x80047601},
{"sundev/vuid_event.h",	"VUIDSADDR",	0x80047603},
{"scsi/targets/srdef.h",	"CDROMPLAYMSF",	0x8006630c},
{"sundev/srreg.h",	"CDROMPLAYMSF",	0x8006630c},
{"sun/dkio.h",	"DKIOCSTYPE",	0x8006647d},
{"sys/ttold.h",	"TIOCSETP",	0x80067409},
{"sys/ttold.h",	"TIOCSETN",	0x8006740a},
{"sys/ttold.h",	"TIOCSETC",	0x80067411},
{"sys/ttold.h",	"TIOCSLTC",	0x80067475},
{"sun/isdnio.h",	"ISDN_SET_LOOPBACK",	0x8008410e},
{"sun/isdnio.h",	"ISDN_RESET_LOOPBACK",	0x8008410f},
{"sundev/lightpenreg.h",	"LIGHTPEN_CALIBRATE",	0x80084c01},
{"sun/tvio.h",	"TVIOSPOS",	0x8008581c},
{"sun/dkio.h",	"DKIOCSPART",	0x80086405},
{"sun/dkio.h",	"FDKSETSEARCH",	0x8008646b},
{"sunwindow/win_ioctl.h",	"WINSETLINK",	0x80086701},
{"sunwindow/win_ioctl.h",	"WINSETRECT",	0x8008670b},
{"sunwindow/win_ioctl.h",	"WINSETSAVEDRECT",	0x8008670c},
{"sunwindow/win_ioctl.h",	"WINPARTIALREPAIR",	0x8008672b},
{"sunwindow/win_ioctl.h",	"WINSETEVENTTIMEOUT",	0x8008673b},
{"sunwindow/win_ioctl.h",	"WINDBLSET",	0x8008674b},
{"sunwindow/win_ioctl.h",	"WINSETPLAYINTR",	0x800867cc},
{"sys/mtio.h",	"MTIOCTOP",	0x80086d01},
{"net/nit_buf.h",	"NIOCSTIME",	0x80087006},
{"sbusdev/gtreg.h",	"FB_VMBACK",	0x80087415},
{"sbusdev/gtreg.h",	"FB_VMUNBACK",	0x80087416},
{"sbusdev/gtreg.h",	"FB_SETLIGHTPENPARAM",	0x8008741a},
{"sbusdev/gtreg.h",	"FB_SETGAMMA",	0x8008741f},
{"sys/ttycom.h",	"TIOCSSIZE",	0x80087425},
{"sys/ttold.h",	"_O_TIOCSSIZE",	0x80087467},
{"sys/ttycom.h",	"TIOCSWINSZ",	0x80087467},
{"sun/isdnio.h",	"ISDN_SET_PARAM",	0x800c4110},
{"sun/fbio.h",	"FBIO_WID_FREE",	0x800c461f},
{"sun/fbio.h",	"FBIO_WID_PUT",	0x800c4620},
{"sun/fbio.h",	"FBIO_WID_GET",	0x800c4621},
{"sundev/lightpenreg.h",	"LIGHTPEN_FILTER",	0x800c4c02},
{"sundev/fdreg.h",	"V_FORMAT",	0x800c5605},
{"sundev/srreg.h",	"CDROMREADMODE2",	0x800c636e},
{"sundev/srreg.h",	"CDROMREADMODE1",	0x800c636f},
{"sunwindow/win_ioctl.h",	"WINSETCURSOR",	0x800c6707},
{"sunwindow/win_ioctl.h",	"WINSETFOCUSEVENT",	0x800c6746},
{"sunwindow/win_ioctl.h",	"WINSETSWALLOWEVENT",	0x800c6748},
{"sundev/msio.h",	"MSIOSETPARMS",	0x800c6d03},
{"sbusdev/gtreg.h",	"FB_CLUTFREE",	0x800c7402},
{"sbusdev/gtreg.h",	"FB_VMCTL",	0x800c741e},
{"pixrect/cg8var.h",	"PIPIO_S_EMULATION_MODE",	0x800e5804},
{"sunwindow/win_ioctl.h",	"WINSCREENPOSITIONS",	0x8010672b},
{"sundev/kbio.h",	"KIOCSETKEY",	0x80106b01},
{"sun/ndio.h",	"NDIOCETHER",	0x80106e08},
{"sys/termio.h",	"TCSETA",	0x80125402},
{"termio.h",	"TCSETA",	0x80125402},
{"sys/termio.h",	"TCSETAW",	0x80125403},
{"termio.h",	"TCSETAW",	0x80125403},
{"sys/termio.h",	"TCSETAF",	0x80125404},
{"termio.h",	"TCSETAF",	0x80125404},
{"sun/fbio.h",	"FBIOPUTCMAP",	0x80144603},
{"sun/fbio.h",	"FBIOGETCMAP",	0x80144604},
{"sunwindow/win_ioctl.h",	"WINSETAVAILPLANEGROUPS",	0x80146741},
{"sunwindow/win_ioctl.h",	"WINSETSYNCPT",	0x801467cd},
{"sundev/kbio.h",	"KIOCSKEY",	0x80146b0c},
{"sun/fbio.h",	"FBIODBLSINFO",	0x80184613},
{"sun/gpio.h",	"GP1IO_PUT_INFO",	0x80184700},
{"sun/dkio.h",	"DKIOCSCMD",	0x80186477},
{"sunwindow/win_ioctl.h",	"WINSETINPUTDEV",	0x80186732},
{"sun/ndio.h",	"NDIOCUSER",	0x80186e03},
{"sun/fbio.h",	"FBIOPUTCMAPI",	0x801c4629},
{"sun/fbio.h",	"FBIOGETCMAPI",	0x801c462a},
{"sun/dkio.h",	"FDKIOSCHAR",	0x801c6471},
{"sbusdev/gtreg.h",	"FB_CLUTPOST",	0x801c7404},
{"sbusdev/bpp_io.h",	"BPPIOC_SETPARMS",	0x80206201},
{"sys/sockio.h",	"SIOCSIFADDR",	0x8020690c},
{"sys/sockio.h",	"SIOCSIFDSTADDR",	0x8020690e},
{"sys/sockio.h",	"SIOCSIFFLAGS",	0x80206910},
{"sys/sockio.h",	"SIOCSIFMEM",	0x80206912},
{"sys/sockio.h",	"SIOCSIFMTU",	0x80206915},
{"sys/sockio.h",	"SIOCSIFBRDADDR",	0x80206918},
{"sys/sockio.h",	"SIOCSIFNETMASK",	0x8020691a},
{"sys/sockio.h",	"SIOCSIFMETRIC",	0x8020691c},
{"sys/sockio.h",	"SIOCUPPER",	0x80206928},
{"sys/sockio.h",	"SIOCLOWER",	0x80206929},
{"sys/sockio.h",	"SIOCSETSYNC",	0x8020692c},
{"sys/sockio.h",	"SIOCADDMULTI",	0x80206931},
{"sys/sockio.h",	"SIOCDELMULTI",	0x80206932},
{"sys/sockio.h",	"SIOCFDRESET",	0x80206933},
{"sys/sockio.h",	"SIOCFDSLEEP",	0x80206934},
{"sys/sockio.h",	"SIOCLDNSTRTFW",	0x80206936},
{"sys/sockio.h",	"SIOCGETFDSTAT",	0x80206937},
{"sys/sockio.h",	"SIOCFDNMIINT",	0x80206938},
{"sys/sockio.h",	"SIOCFDEXUSER",	0x80206939},
{"sys/sockio.h",	"SIOCFDGNETMAP",	0x8020693a},
{"sys/sockio.h",	"SIOCFDGIOCTL",	0x8020693b},
{"net/nit_if.h",	"NIOCBIND",	0x80207003},
{"sbusdev/gtreg.h",	"FB_GT_SETVERSION",	0x80207428},
{"sys/stropts.h",	"I_FDINSERT",	0x80245310},
{"stropts.h",	"I_FDINSERT",	0x80245310},
{"termios.h",	"TCSETS",	0x80245409},
{"sys/termios.h",	"TCSETS",	0x80245409},
{"termios.h",	"TCSETSW",	0x8024540a},
{"sys/termios.h",	"TCSETSW",	0x8024540a},
{"termios.h",	"TCSETSF",	0x8024540b},
{"sys/termios.h",	"TCSETSF",	0x8024540b},
{"sys/sockio.h",	"SIOCSARP",	0x8024691e},
{"sys/sockio.h",	"SIOCDARP",	0x80246920},
{"sys/sockio.h",	"SIOCSNIT",	0x80247000},
{"sun/dkio.h",	"DKIOCSGEOM",	0x80266403},
{"sun/fbio.h",	"FBIOSATTR",	0x80284605},
{"sun/fbio.h",	"FBIOSCURSOR",	0x802c4618},
{"sunwindow/win_ioctl.h",	"WINSETLOCATOR",	0x80306730},
{"sunwindow/win_ioctl.h",	"WINSETCPCURSOR",	0x80306796},
{"sbusdev/audio_79C30.h",	"AUDIOSETREG",	0x80306902},
{"sys/sockio.h",	"SIOCADDRT",	0x8030720a},
{"sys/sockio.h",	"SIOCDELRT",	0x8030720b},
{"sunwindow/win_ioctl.h",	"WINSETKBDMASK",	0x80346736},
{"sunwindow/win_ioctl.h",	"WINSETPICKMASK",	0x80346737},
{"sun/dkio.h",	"FDKSETDRIVECHAR",	0x8038646d},
{"sun/tvio.h",	"TVIOSVIDEOCAL",	0x80405832},
{"sun/tvio.h",	"TVIONVWRITE",	0x80405834},
{"sun/dkio.h",	"DKIOCSAPART",	0x8040647b},
{"sunwindow/win_ioctl.h",	"WINSETSCALING",	0x80406727},
{"net/nit_pf.h",	"NIOCSETF",	0x80527002},
{"pixrect/gp1var.h",	"GP1IO_SATTR",	0x80584765},
{"sunwindow/win_ioctl.h",	"WINSETINPUTMASK",	0x806c6714},
{"sunwindow/win_ioctl.h",	"WINSCREENNEW",	0x80706728},
{"sunwindow/win_ioctl.h",	"WINSETKBD",	0x8070672e},
{"sunwindow/win_ioctl.h",	"WINSETMS",	0x8070672f},
