{"linux/lp.h",	"LPCHAR",	0x1},
{"linux/if_ether.h",	"ETH_P_802_3",	0x1},
{"linux/route.h",	"RTF_UP",	0x1},
{"linux/lp.h",	"LPTIME",	0x2},
{"linux/if_ether.h",	"ETH_P_AX25",	0x2},
{"linux/route.h",	"RTF_GATEWAY",	0x2},
{"linux/if_ether.h",	"ETH_P_ALL",	0x3},
{"linux/lp.h",	"LPABORT",	0x4},
{"linux/route.h",	"RTF_HOST",	0x4},
{"linux/lp.h",	"LPSETIRQ",	0x5},
{"linux/lp.h",	"LPGETIRQ",	0x6},
{"linux/lp.h",	"LPWAIT",	0x8},
{"linux/route.h",	"RTF_REINSTATE",	0x8},
{"linux/route.h",	"RTF_DYNAMIC",	0x10},
{"linux/route.h",	"RTF_MODIFIED",	0x20},
{"linux/if_ether.h",	"ETH_P_LOOP",	0x60},
{"linux/if_ether.h",	"ETH_P_ECHO",	0x200},
{"linux/sbpcd.h",	"CDROM_PORT",	0x230},
{"linux/a.out.h",	"SEGMENT_SIZE",	0x400},
{"linux/if_ether.h",	"ETH_P_PUP",	0x400},
{"linux/if_ether.h",	"ETH_P_IP",	0x800},
{"linux/if_ether.h",	"ETH_P_X25",	0x805},
{"linux/if_ether.h",	"ETH_P_ARP",	0x806},
{"linux/shm.h",	"SHMLBA",	0x1000},
{"linux/sockios.h",	"IP_SET_DEV",	0x2401},
{"linux/kd.h",	"SWAPMONO",	0x4b00},
{"linux/kd.h",	"SWAPCGA",	0x4b01},
{"linux/kd.h",	"SWAPEGA",	0x4b02},
{"linux/kd.h",	"SWAPVGA",	0x4b03},
{"linux/kd.h",	"CONS_CURRENT",	0x4b04},
{"linux/kd.h",	"SW_B40x25",	0x4b05},
{"linux/kd.h",	"SW_C40x25",	0x4b06},
{"linux/kd.h",	"SW_B80x25",	0x4b07},
{"linux/kd.h",	"SW_C80x25",	0x4b08},
{"linux/kd.h",	"SW_BG320",	0x4b09},
{"linux/kd.h",	"SW_CG320",	0x4b0a},
{"linux/kd.h",	"SW_BG640",	0x4b0b},
{"linux/kd.h",	"SW_CG320_D",	0x4b0c},
{"linux/kd.h",	"SW_CG640_E",	0x4b0d},
{"linux/kd.h",	"SW_EGAMONOAPA",	0x4b0e},
{"linux/kd.h",	"SW_ENH_MONOAPA2",	0x4b0f},
{"linux/kd.h",	"SW_CG640x350",	0x4b10},
{"linux/kd.h",	"SW_ENH_CG640",	0x4b11},
{"linux/kd.h",	"SW_EGAMONO80x25",	0x4b12},
{"linux/kd.h",	"SW_ENHB40x25",	0x4b13},
{"linux/kd.h",	"SW_ENHC40x25",	0x4b14},
{"linux/kd.h",	"SW_ENHB80x25",	0x4b15},
{"linux/kd.h",	"SW_ENHC80x25",	0x4b16},
{"linux/kd.h",	"SW_ENHB80x43",	0x4b17},
{"linux/kd.h",	"SW_ENHC80x43",	0x4b18},
{"linux/kd.h",	"SW_MCAMODE",	0x4b19},
{"linux/kd.h",	"SW_ATT640",	0x4b1a},
{"linux/kd.h",	"CONS_GET",	0x4b1b},
{"linux/kd.h",	"MCA_GET",	0x4b1c},
{"linux/kd.h",	"CGA_GET",	0x4b1d},
{"linux/kd.h",	"EGA_GET",	0x4b1e},
{"linux/kd.h",	"MAPCONS",	0x4b1f},
{"linux/kd.h",	"MAPMONO",	0x4b20},
{"linux/kd.h",	"MAPCGA",	0x4b21},
{"linux/kd.h",	"MAPEGA",	0x4b22},
{"linux/kd.h",	"MAPVGA",	0x4b23},
{"linux/kd.h",	"MCAIO",	0x4b24},
{"linux/kd.h",	"CGAIO",	0x4b25},
{"linux/kd.h",	"EGAIO",	0x4b26},
{"linux/kd.h",	"VGAIO",	0x4b27},
{"linux/kd.h",	"GIO_FONT8x8",	0x4b28},
{"linux/kd.h",	"PIO_FONT8x8",	0x4b29},
{"linux/kd.h",	"GIO_FONT8x14",	0x4b2a},
{"linux/kd.h",	"PIO_FONT8x14",	0x4b2b},
{"linux/kd.h",	"GIO_FONT8x16",	0x4b2c},
{"linux/kd.h",	"PIO_FONT8x16",	0x4b2d},
{"linux/kd.h",	"KDDISPTYPE",	0x4b2e},
{"linux/kd.h",	"KIOCSOUND",	0x4b2f},
{"linux/kd.h",	"KDMKTONE",	0x4b30},
{"linux/kd.h",	"KDGETLED",	0x4b31},
{"linux/kd.h",	"KDSETLED",	0x4b32},
{"linux/kd.h",	"KDGKBTYPE",	0x4b33},
{"linux/kd.h",	"KDADDIO",	0x4b34},
{"linux/kd.h",	"KDDELIO",	0x4b35},
{"linux/kd.h",	"KDENABIO",	0x4b36},
{"linux/kd.h",	"KDDISABIO",	0x4b37},
{"linux/kd.h",	"KDQUEMODE",	0x4b38},
{"linux/kd.h",	"KDSBORDER",	0x4b39},
{"linux/kd.h",	"KDSETMODE",	0x4b3a},
{"linux/kd.h",	"KDGETMODE",	0x4b3b},
{"linux/kd.h",	"KDMAPDISP",	0x4b3c},
{"linux/kd.h",	"KDUNMAPDISP",	0x4b3d},
{"linux/kd.h",	"KDVDCTYPE",	0x4b3e},
{"linux/kd.h",	"KIOCINFO",	0x4b3f},
{"linux/kd.h",	"GIO_SCRNMAP",	0x4b40},
{"linux/kd.h",	"PIO_SCRNMAP",	0x4b41},
{"linux/kd.h",	"GIO_ATTR",	0x4b42},
{"linux/kd.h",	"GIO_COLOR",	0x4b43},
{"linux/kd.h",	"KDGKBMODE",	0x4b44},
{"linux/kd.h",	"KDSKBMODE",	0x4b45},
{"linux/kd.h",	"KDGKBENT",	0x4b46},
{"linux/kd.h",	"KDSKBENT",	0x4b47},
{"linux/kd.h",	"KDGKBSENT",	0x4b48},
{"linux/kd.h",	"KDSKBSENT",	0x4b49},
{"linux/kd.h",	"KDGKBDIACR",	0x4b4a},
{"linux/kd.h",	"KDSKBDIACR",	0x4b4b},
{"linux/kd.h",	"GIO_FONT",	0x4b60},
{"linux/kd.h",	"PIO_FONT",	0x4b61},
{"linux/kd.h",	"KDGKBMETA",	0x4b62},
{"linux/kd.h",	"KDSKBMETA",	0x4b63},
{"linux/cdrom.h",	"CDROMPAUSE",	0x5301},
{"linux/cdrom.h",	"CDROMRESUME",	0x5302},
{"linux/cdrom.h",	"CDROMPLAYMSF",	0x5303},
{"linux/cdrom.h",	"CDROMPLAYTRKIND",	0x5304},
{"linux/cdrom.h",	"CDROMREADTOCHDR",	0x5305},
{"linux/cdrom.h",	"CDROMREADTOCENTRY",	0x5306},
{"linux/cdrom.h",	"CDROMSTOP",	0x5307},
{"linux/cdrom.h",	"CDROMSTART",	0x5308},
{"linux/cdrom.h",	"CDROMEJECT",	0x5309},
{"linux/cdrom.h",	"CDROMVOLCTRL",	0x530a},
{"linux/cdrom.h",	"CDROMSUBCHNL",	0x530b},
{"linux/cdrom.h",	"CDROMREADMODE2",	0x530c},
{"linux/cdrom.h",	"CDROMREADMODE1",	0x530d},
{"linux/termios.h",	"TCGETS",	0x5401},
{"linux/termios.h",	"TCSETS",	0x5402},
{"linux/termios.h",	"TCSETSW",	0x5403},
{"linux/termios.h",	"TCSETSF",	0x5404},
{"linux/termios.h",	"TCGETA",	0x5405},
{"linux/termios.h",	"TCSETA",	0x5406},
{"linux/termios.h",	"TCSETAW",	0x5407},
{"linux/termios.h",	"TCSETAF",	0x5408},
{"linux/termios.h",	"TCSBRK",	0x5409},
{"linux/termios.h",	"TCXONC",	0x540a},
{"linux/termios.h",	"TCFLSH",	0x540b},
{"linux/termios.h",	"TIOCEXCL",	0x540c},
{"linux/termios.h",	"TIOCNXCL",	0x540d},
{"linux/termios.h",	"TIOCSCTTY",	0x540e},
{"linux/termios.h",	"TIOCGPGRP",	0x540f},
{"linux/termios.h",	"TIOCSPGRP",	0x5410},
{"linux/termios.h",	"TIOCOUTQ",	0x5411},
{"linux/termios.h",	"TIOCSTI",	0x5412},
{"linux/termios.h",	"TIOCGWINSZ",	0x5413},
{"linux/termios.h",	"TIOCSWINSZ",	0x5414},
{"linux/termios.h",	"TIOCMGET",	0x5415},
{"linux/termios.h",	"TIOCMBIS",	0x5416},
{"linux/termios.h",	"TIOCMBIC",	0x5417},
{"linux/termios.h",	"TIOCMSET",	0x5418},
{"linux/termios.h",	"TIOCGSOFTCAR",	0x5419},
{"linux/termios.h",	"TIOCSSOFTCAR",	0x541a},
{"linux/termios.h",	"FIONREAD",	0x541b},
{"linux/termios.h",	"TIOCLINUX",	0x541c},
{"linux/termios.h",	"TIOCCONS",	0x541d},
{"linux/termios.h",	"TIOCGSERIAL",	0x541e},
{"linux/termios.h",	"TIOCSSERIAL",	0x541f},
{"linux/termios.h",	"TIOCPKT",	0x5420},
{"linux/termios.h",	"FIONBIO",	0x5421},
{"linux/termios.h",	"TIOCNOTTY",	0x5422},
{"linux/termios.h",	"TIOCSETD",	0x5423},
{"linux/termios.h",	"TIOCGETD",	0x5424},
{"linux/termios.h",	"TCSBRKP",	0x5425},
{"linux/termios.h",	"FIONCLEX",	0x5450},
{"linux/termios.h",	"FIOCLEX",	0x5451},
{"linux/termios.h",	"FIOASYNC",	0x5452},
{"linux/termios.h",	"TIOCSERCONFIG",	0x5453},
{"linux/termios.h",	"TIOCSERGWILD",	0x5454},
{"linux/termios.h",	"TIOCSERSWILD",	0x5455},
{"linux/termios.h",	"TIOCGLCKTRMIOS",	0x5456},
{"linux/termios.h",	"TIOCSLCKTRMIOS",	0x5457},
{"linux/vt.h",	"VT_OPENQRY",	0x5600},
{"linux/vt.h",	"VT_GETMODE",	0x5601},
{"linux/vt.h",	"VT_SETMODE",	0x5602},
{"linux/vt.h",	"VT_GETSTATE",	0x5603},
{"linux/vt.h",	"VT_SENDSIG",	0x5604},
{"linux/vt.h",	"VT_RELDISP",	0x5605},
{"linux/vt.h",	"VT_ACTIVATE",	0x5606},
{"linux/vt.h",	"VT_WAITACTIVE",	0x5607},
{"linux/if_ether.h",	"ETH_P_RARP",	0x8035},
{"linux/if_ether.h",	"ETH_P_IPX",	0x8137},
{"linux/sockios.h",	"FIOSETOWN",	0x8901},
{"linux/sockios.h",	"SIOCSPGRP",	0x8902},
{"linux/sockios.h",	"FIOGETOWN",	0x8903},
{"linux/sockios.h",	"SIOCGPGRP",	0x8904},
{"linux/sockios.h",	"SIOCATMARK",	0x8905},
{"linux/sockios.h",	"SIOCADDRT",	0x890b},
{"linux/sockios.h",	"SIOCDELRT",	0x890c},
{"linux/sockios.h",	"SIOCGIFNAME",	0x8910},
{"linux/sockios.h",	"SIOCSIFLINK",	0x8911},
{"linux/sockios.h",	"SIOCGIFCONF",	0x8912},
{"linux/sockios.h",	"SIOCGIFFLAGS",	0x8913},
{"linux/sockios.h",	"SIOCSIFFLAGS",	0x8914},
{"linux/sockios.h",	"SIOCGIFADDR",	0x8915},
{"linux/sockios.h",	"SIOCSIFADDR",	0x8916},
{"linux/sockios.h",	"SIOCGIFDSTADDR",	0x8917},
{"linux/sockios.h",	"SIOCSIFDSTADDR",	0x8918},
{"linux/sockios.h",	"SIOCGIFBRDADDR",	0x8919},
{"linux/sockios.h",	"SIOCSIFBRDADDR",	0x891a},
{"linux/sockios.h",	"SIOCGIFNETMASK",	0x891b},
{"linux/sockios.h",	"SIOCSIFNETMASK",	0x891c},
{"linux/sockios.h",	"SIOCGIFMETRIC",	0x891d},
{"linux/sockios.h",	"SIOCSIFMETRIC",	0x891e},
{"linux/sockios.h",	"SIOCGIFMEM",	0x891f},
{"linux/sockios.h",	"SIOCSIFMEM",	0x8920},
{"linux/sockios.h",	"SIOCGIFMTU",	0x8921},
{"linux/sockios.h",	"SIOCSIFMTU",	0x8922},
{"linux/sockios.h",	"SIOCGIFHWADDR",	0x8923},
{"linux/sockios.h",	"SIOCSIFHWADDR",	0x8924},
{"linux/sockios.h",	"SIOCGIFENCAP",	0x8925},
{"linux/sockios.h",	"SIOCSIFENCAP",	0x8926},
{"linux/sockios.h",	"SIOCADDRTOLD",	0x8940},
{"linux/sockios.h",	"SIOCDELRTOLD",	0x8941},
{"linux/sockios.h",	"SIOCDARP",	0x8950},
{"linux/sockios.h",	"SIOCGARP",	0x8951},
{"linux/sockios.h",	"SIOCSARP",	0x8952},
{"linux/ddi.h",	"DDIOCSDBG",	0x9000},
{"linux/ddi.h",	"DDIOCGNAME",	0x9001},
{"linux/ddi.h",	"DDIOCGCONF",	0x9002},
{"linux/ddi.h",	"DDIOCSCONF",	0x9003},
{"linux/soundcard.h",	"SNDCTL_SEQ_PERCMODE",	0x40045106},
{"linux/soundcard.h",	"SNDCTL_SEQ_TESTMIDI",	0x40045108},
{"linux/soundcard.h",	"SNDCTL_SEQ_RESETSAMPLES",	0x40045109},
{"linux/soundcard.h",	"SNDCTL_SEQ_TRESHOLD",	0x4004510d},
{"linux/soundcard.h",	"SNDCTL_FM_4OP_ENABLE",	0x4004510f},
{"linux/ext2_fs.h",	"EXT2_IOC_SETFLAGS",	0x40046602},
{"linux/ext2_fs.h",	"EXT2_IOC_SETVERSION",	0x40047602},
{"linux/soundcard.h",	"MIXER_IOCTL_SET_PARAMS",	0x40057315},
{"linux/mtio.h",	"MTIOCTOP",	0x40086d01},
{"linux/soundcard.h",	"MIXER_IOCTL_SET_LEVELS",	0x400b7314},
{"linux/soundcard.h",	"SNDCTL_FM_LOAD_INSTR",	0x40285107},
{"linux/soundcard.h",	"SOUND_PCM_READ_RATE",	0x80045002},
{"linux/soundcard.h",	"SOUND_PCM_READ_BITS",	0x80045005},
{"linux/soundcard.h",	"SOUND_PCM_READ_CHANNELS",	0x80045006},
{"linux/soundcard.h",	"SOUND_PCM_READ_FILTER",	0x80045007},
{"linux/soundcard.h",	"SNDCTL_SEQ_GETOUTCOUNT",	0x80045104},
{"linux/soundcard.h",	"SNDCTL_SEQ_GETINCOUNT",	0x80045105},
{"linux/soundcard.h",	"SNDCTL_SEQ_NRSYNTHS",	0x8004510a},
{"linux/soundcard.h",	"SNDCTL_SEQ_NRMIDIS",	0x8004510b},
{"linux/ext2_fs.h",	"EXT2_IOC_GETFLAGS",	0x80046601},
{"linux/mtio.h",	"MTIOCPOS",	0x80046d03},
{"linux/ext2_fs.h",	"EXT2_IOC_GETVERSION",	0x80047601},
{"linux/soundcard.h",	"MIXER_IOCTL_READ_PARAMS",	0x80057317},
{"linux/soundcard.h",	"MIXER_IOCTL_READ_LEVELS",	0x800b7316},
{"linux/mtio.h",	"MTIOCGET",	0x801c6d02},
{"linux/soundcard.h",	"SNDCTL_DSP_RESET",	0x5000},
{"linux/soundcard.h",	"SNDCTL_DSP_SYNC",	0x5001},
{"linux/soundcard.h",	"SNDCTL_DSP_POST",	0x5008},
{"linux/soundcard.h",	"SNDCTL_SEQ_RESET",	0x5100},
{"linux/soundcard.h",	"SNDCTL_SEQ_SYNC",	0x5101},
{"linux/soundcard.h",	"MIXER_IOCTL_RESET",	0x7318},
